@@ -11,10 +11,11 @@ import cairo
 import xml.dom.minidom as xmlparser
 import urllib
 import gio
-
+import inspect
 PATH = "/apps/digghomewidget"
-KEY = "/apps/digghomewidget/selected_category"
-
+CATGR = "/apps/digghomewidget/selected_category"
+NUM = "/apps/digghomewidget/number_of_stories"
+THMB = "/apps/digghomewidget/load_thumbnails"
 class diggItem:
     def __init__(self, title, href, topic, diggs):
         self.title = title
@@ -27,6 +28,7 @@ class diggLoader:
     def __init__(self, callback):
         self.callback = callback
         self.stream = None
+        self.load_thumbnails = True
 
     def parse_and_return(self, daemonfile, result):
         try:
@@ -34,6 +36,7 @@ class diggLoader:
         except Exception, e:
             doc = None
             print "Can't connect to Digg.com"
+            self.callback(list=None)
         if doc != None:
             stories = doc.getElementsByTagName("story")
             if len(stories) == 0:
@@ -47,21 +50,22 @@ class diggLoader:
                 diggs = story.getAttribute("diggs")
                 topic = story.getElementsByTagName("topic")[0]
                 topic = topic.getAttribute("name")
-                thumbnail = None
-                thumbnail = story.getElementsByTagName("thumbnail")
-                if thumbnail.length > 0:
-                    thumbnail = thumbnail[0]
-                    thumbnail = thumbnail.getAttribute("src")
                 item = diggItem(title, href, topic, diggs) 
         #        print thumbnail
-                try:
-                    if thumbnail != None and thumbnail != "":
-                        g = urllib.urlopen(thumbnail)
-                        img = g.read()
-                        item.thumbnail = img
-                    #print item.thumbnail
-                except:
-                    item.thumbnail = None
+                if self.load_thumbnails:
+                    thumbnail = None
+                    thumbnail = story.getElementsByTagName("thumbnail")
+                    if thumbnail.length > 0:
+                        thumbnail = thumbnail[0]
+                        thumbnail = thumbnail.getAttribute("src")
+                    try:
+                        if thumbnail != None and thumbnail != "":
+                            g = urllib.urlopen(thumbnail)
+                            img = g.read()
+                            item.thumbnail = img
+                        #print item.thumbnail
+                    except:
+                        item.thumbnail = None
                 list.append(item)
             self.callback(list)
 
@@ -104,10 +108,10 @@ class DiggItemWidget(hildon.Button):
         rect = self.get_allocation()
         context.rectangle(rect.x, rect.y, rect.width, rect.height)
 #        print rect.height
-#        if self.state == 1:
-#            context.set_source_rgb(0.7, 0.4, 0.3)
-#        else: 
-        context.set_source_rgb(1,1,1)
+        if self.state == 1:
+            context.set_source_rgb(0.7, 0.4, 0.3)
+        else: 
+            context.set_source_rgb(1,1,1)
         context.fill()
         offset = 5
         if self.item.thumbnail != None:
@@ -237,15 +241,35 @@ class CustomAlignment(gtk.Alignment):
 class DiggHomePlugin(hildondesktop.HomePluginItem):
     def __init__(self):
         hildondesktop.HomePluginItem.__init__(self)
+#        print "ALL:", dir(self)
+        self.set_default_size(300, 150)
+        self.set_geometry_hints(self, 300, 100, 300, 600)
+        self.set_settings(True)
+        self.connect("show-settings", self.show_settings)
+        self.loader = diggLoader(self.update) 
         self.client = gconf.client_get_default()
-        temp = self.client.get_string(KEY)
-        if temp != None:
+        temp = self.client.get_string(CATGR)
+        if temp != None and temp !="":
             self.category = temp 
         else:
             self.category = "All"
-        self.count = 4
+        temp = self.client.get_int(NUM)
+        if temp == 0:
+            self.count = 2
+            self.checkbox_active = True 
+            self.loader.load_thumbnails = True 
+        if temp != None:
+            self.count = temp 
+        else:
+            self.count = 2
+        temp = self.client.get_bool(THMB)
+        if temp != None:
+            self.checkbox_active = temp 
+            self.loader.load_thumbnails = temp 
+        else:
+            self.checkbox_active = True 
+            self.loader.load_thumbnails = True 
         self.hotness = "Top"
-        self.loader = diggLoader(self.update) 
         container = gtk.Alignment(0.0,0.0,1.0,1.0)
         container.set_padding(2,1,0,0)
         self.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse("#1B5790"))
@@ -282,10 +306,15 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
         container.add(mainVBox)
         container.show_all()
         self.add(container)
-        self.set_size_request(300, -1)
+        self.connect("notify::is-on-current-desktop", self.on_desktop)
+#        self.set_size_request(300, -1)
         self.loader.get_toplist(container=self.category,count=self.count)
 #        gtk.Settings.gtk-enable-animations = False
 
+    def on_desktop(self, widget, data):
+        self.resize(300, 150+(self.count-1)*(70+1))
+
+
     def update_button(self, widget):
         self.row.title = "Updating..."
         self.row.queue_draw()
@@ -294,22 +323,24 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
 
     def update(self, list):
 #        list = diggapi.get_toplist(container=self.category,count=self.count)
-        children = self.vbox.get_children()
-        for child in children:
-            self.vbox.remove(child)
         if list != None:
-            for item in list:
-                button = DiggItemWidget(item)
-                self.vbox.add(button)
-        self.show_all()
-        self.client.set_string(KEY, self.category)
-        title = self.category
-        title = title.replace("_", "&")
-        if title == "":
-            title = "All"
-        self.row.title = title 
-        self.row.queue_draw()
-        return False
+            children = self.vbox.get_children()
+            for child in children:
+                self.vbox.remove(child)
+            if list != None:
+                for item in list:
+                    button = DiggItemWidget(item)
+                    self.vbox.add(button)
+            self.show_all()
+            self.client.set_string(KEY, self.category)
+            title = self.category
+            title = title.replace("_", "&")
+            if title == "":
+                title = "All"
+            self.row.title = title 
+            self.row.queue_draw()
+        else:
+            hildon.hildon_banner_show_information(self, "None", "Can't connect to digg.com. Please check your internet connection.")
 
 
     def category_changed(self, button, user_data=None):
@@ -347,6 +378,49 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
         current_selection = selector.get_current_text()
 #        print current_selection
 
+    def show_settings(self, widget):
+        dialog = gtk.Dialog()
+        dialog.set_transient_for(self)
+        dialog.set_title("Settings")
+        thumbn_checkbox = hildon.CheckButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
+        thumbn_checkbox.set_label("Load thumbnails")
+        dialog.add_button("Save", gtk.RESPONSE_OK)
+        selector = hildon.TouchSelector(text = True)
+        selector.append_text("1")
+        selector.append_text("2")
+        selector.append_text("3")
+        selector.append_text("4")
+        num_itemsPicker = hildon.PickerButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        num_itemsPicker.set_title("Number of stories")
+        num_itemsPicker.set_selector(selector)
+        num_itemsPicker.set_alignment(0.0, 0.5, 1.0, 1.0)
+        num_itemsPicker.set_active(self.count-1)
+        thumbn_checkbox.set_active(self.loader.load_thumbnails)
+        thumbn_checkbox.connect("toggled", self.checkbox_toggle)
+        dialog.vbox.add(num_itemsPicker)
+        dialog.vbox.add(thumbn_checkbox)
+        dialog.show_all()
+        response = dialog.run()
+        dialog.destroy()
+        if response == gtk.RESPONSE_OK:
+            oldcount = self.count
+            cursize = self.get_size()
+            self.count = num_itemsPicker.get_active() + 1 
+            sep = oldcount - self.count
+            self.loader.load_thumbnails = self.checkbox_active 
+            self.client.set_int(NUM, self.count)
+            self.client.set_bool(THMB, self.loader.load_thumbnails)
+            children = self.vbox.get_children()
+            for child in children:
+                self.vbox.remove(child)
+            self.vbox.set_size_request(-1, self.count*(70+1)-1)
+            self.set_size_request(300, cursize[1]-(sep*(70+1)))
+            self.resize(300, cursize[1]-(sep*(70+1)))
+            self.update_button(self)
+
+    def checkbox_toggle(self, widget):
+        self.checkbox_active =  widget.get_active()
+
 hd_plugin_type = DiggHomePlugin
 
 
